@@ -294,7 +294,7 @@ class DFSBase(object):
 
             CurrentDirectory = os.getcwd()
             os.chdir(mz)    
-            hllDll = WinDLL("ufs.dll")
+            hllDll = WinDLL(os.path.join(mz, "ufs.dll"))
             os.chdir(CurrentDirectory) #Reset to current directory
 
 
@@ -364,6 +364,7 @@ class DFSBase(object):
         cls = TemplateFile.new_file(file_name, TemplateFile.number_of_items)
         cls._copy_item_info(TemplateFile)
         cls.__copy_from_template(TemplateFile)
+        TemplateFile.dispose()
         return cls
 
 
@@ -689,12 +690,16 @@ class DFSBase(object):
         time = 0
         if self.time_axis is TimeAxisType.CalendarNonEquidistant and self._currentTimeStep > 0 :
             ts = self.time_steps[TimeStep] - self.start_time
-            if self.time_step_unit is TimeInterval.Second:
-                time = ts.total_seconds()
-            elif self.time_step_unit is TimeInterval.Minute:
-                time = ts.total_minutes()
-            elif self.time_step_unit is TimeInterval.Hour:
-                time = ts.total_hours()
+        else:
+            ts = self.time_step_size
+        if self.time_step_unit is TimeInterval.Second:
+            time = ts.total_seconds()
+        elif self.time_step_unit is TimeInterval.Minute:
+            time = ts.total_seconds()/60
+        elif self.time_step_unit is TimeInterval.Hour:
+            time = ts.total_seconds()/3600
+        
+        time*=TimeStep
 
       
       #Do we need to also add a new timestep
@@ -902,6 +907,21 @@ class DFS0(DFSBase):
         """
         return pd.Series(self.get_values(Item), index=self.time_steps)
 
+    def get_all_data(self):
+        """
+        Gets all data as a Pandas series
+        """
+         # initialize dataframe
+        dat = pd.DataFrame(index=self.time_steps, columns=[it.name for it in self.items])
+
+        # read item by item
+        for i, it in enumerate(self.items):
+            dat[it.name] = self.get_timeseries(i+1)
+
+        # set delete value to np.nan
+        dat[dat==self.delete_value] = np.nan
+        return dat
+
 
 class DFS2(DFSBase):
     """
