@@ -81,7 +81,6 @@ class DataItem(object):
         self.name = name
         self.chainages =[]
         self.offset=0
-        return super(DataItem, self).__init__()
 
 class River_setup(object):
     """
@@ -90,7 +89,6 @@ class River_setup(object):
     def __init__(self):
         self.nodes=[]
         self.reaches=[]
-        return super(River_setup, self).__init__()
 
     @classmethod
     def from_file(cls, file_name):
